diff lib/gftp.h @ 916:936635b76f02

2007-4-26 Brian Masney <masneyb@gftp.org> * src/gtk/misc-gtk.c lib/gftp.h lib/protocols.c - added filename_utf8_encoded flag to the gftp_file structure. If this is false, then don't attempt to show the filename in the GTK port. The user can still select the blank filename though.
author masneyb
date Thu, 26 Apr 2007 23:47:34 +0000
parents f716c8dbeaff
children 7b5aa0420fe2
line wrap: on
line diff
--- a/lib/gftp.h	Wed Apr 25 22:23:16 2007 +0000
+++ b/lib/gftp.h	Thu Apr 26 23:47:34 2007 +0000
@@ -257,8 +257,11 @@
                done_rm : 1,	/* Remove the file when done */
                transfer_done : 1, /* Is current file transfer done? */
                retry_transfer : 1, /* Is current file transfer done? */
-               exists_other_side; /* The file exists on the other side during
-                                     the file transfer */
+               exists_other_side : 1, /* The file exists on the other side
+                                         during the file transfer */
+               filename_utf8_encoded : 1; /* Is the filename properly UTF8
+                                             encoded? */
+
   char transfer_action;		/* See the GFTP_TRANS_ACTION_* vars above */
   /*@null@*/ void *user_data;
 };